@@ -37,9 +37,9 @@ impl Docker {
     /// Create the base `Command` for running Docker.
     pub fn command(&self) -> Command {
         if self.sudo {
-            Command::with_args("sudo", &["docker"])
+            Command::with_args("sudo", &[&self.program])
         } else {
-            Command::new("docker")
+            Command::new(&self.program)
         }
     }
 
@@ -338,3 +338,20 @@ pub struct RunOpt {
     /// Optional arguments to pass to the command.
     pub args: Vec<OsString>,
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_command() {
+        let mut docker = Docker::new();
+        assert_eq!(docker.command().command_line_lossy(), "docker");
+
+        docker.sudo = true;
+        assert_eq!(docker.command().command_line_lossy(), "sudo docker");
+
+        docker.program = "myCommand".into();
+        assert_eq!(docker.command().command_line_lossy(), "sudo myCommand");
+    }
+}
