@@ -24,6 +24,28 @@ fn test_build() {
     );
 }
 
+#[test]
+fn test_create_network() {
+    assert_eq!(
+        Docker::new()
+            .create_network(CreateNetworkOpt {
+                name: "myNetwork".into(),
+            })
+            .command_line_lossy(),
+        "docker network create myNetwork"
+    );
+}
+
+#[test]
+fn test_remove_network() {
+    assert_eq!(
+        Docker::new()
+            .remove_network("myNetwork".into())
+            .command_line_lossy(),
+        "docker network rm myNetwork"
+    );
+}
+
 #[test]
 fn test_user() {
     let mut user = User {
